@@ -5,6 +5,7 @@ from .answer_pre_checkout_query import AnswerPreCheckoutQuery
 from .answer_shipping_query import AnswerShippingQuery
 from .answer_web_app_query import AnswerWebAppQuery
 from .approve_chat_join_request import ApproveChatJoinRequest
+from .approve_suggested_post import ApproveSuggestedPost
 from .ban_chat_member import BanChatMember
 from .ban_chat_sender_chat import BanChatSenderChat
 from .base import Request, Response, TelegramMethod
@@ -20,6 +21,7 @@ from .create_forum_topic import CreateForumTopic
 from .create_invoice_link import CreateInvoiceLink
 from .create_new_sticker_set import CreateNewStickerSet
 from .decline_chat_join_request import DeclineChatJoinRequest
+from .decline_suggested_post import DeclineSuggestedPost
 from .delete_business_messages import DeleteBusinessMessages
 from .delete_chat_photo import DeleteChatPhoto
 from .delete_chat_sticker_set import DeleteChatStickerSet
@@ -36,6 +38,7 @@ from .edit_chat_subscription_invite_link import EditChatSubscriptionInviteLink
 from .edit_forum_topic import EditForumTopic
 from .edit_general_forum_topic import EditGeneralForumTopic
 from .edit_message_caption import EditMessageCaption
+from .edit_message_checklist import EditMessageChecklist
 from .edit_message_live_location import EditMessageLiveLocation
 from .edit_message_media import EditMessageMedia
 from .edit_message_reply_markup import EditMessageReplyMarkup
@@ -64,6 +67,7 @@ from .get_my_default_administrator_rights import GetMyDefaultAdministratorRights
 from .get_my_description import GetMyDescription
 from .get_my_name import GetMyName
 from .get_my_short_description import GetMyShortDescription
+from .get_my_star_balance import GetMyStarBalance
 from .get_star_transactions import GetStarTransactions
 from .get_sticker_set import GetStickerSet
 from .get_updates import GetUpdates
@@ -91,6 +95,7 @@ from .save_prepared_inline_message import SavePreparedInlineMessage
 from .send_animation import SendAnimation
 from .send_audio import SendAudio
 from .send_chat_action import SendChatAction
+from .send_checklist import SendChecklist
 from .send_contact import SendContact
 from .send_dice import SendDice
 from .send_document import SendDocument
@@ -161,6 +166,7 @@ __all__ = (
     "AnswerShippingQuery",
     "AnswerWebAppQuery",
     "ApproveChatJoinRequest",
+    "ApproveSuggestedPost",
     "BanChatMember",
     "BanChatSenderChat",
     "Close",
@@ -175,6 +181,7 @@ __all__ = (
     "CreateInvoiceLink",
     "CreateNewStickerSet",
     "DeclineChatJoinRequest",
+    "DeclineSuggestedPost",
     "DeleteBusinessMessages",
     "DeleteChatPhoto",
     "DeleteChatStickerSet",
@@ -191,6 +198,7 @@ __all__ = (
     "EditForumTopic",
     "EditGeneralForumTopic",
     "EditMessageCaption",
+    "EditMessageChecklist",
     "EditMessageLiveLocation",
     "EditMessageMedia",
     "EditMessageReplyMarkup",
@@ -219,6 +227,7 @@ __all__ = (
     "GetMyDescription",
     "GetMyName",
     "GetMyShortDescription",
+    "GetMyStarBalance",
     "GetStarTransactions",
     "GetStickerSet",
     "GetUpdates",
@@ -248,6 +257,7 @@ __all__ = (
     "SendAnimation",
     "SendAudio",
     "SendChatAction",
+    "SendChecklist",
     "SendContact",
     "SendDice",
     "SendDocument",
